@@ -3,7 +3,7 @@ from probability.distributions.continuous.continuous_uniform import \
     ContinuousUniform
 from probability.distributions.continuous.exponential import Exponential
 from probability.distributions.continuous.gamma import Gamma
-from probability.distributions.continuous.inv_gamma import InvGamma
+from probability.distributions.continuous.inverse_gamma import InverseGamma
 from probability.distributions.continuous.laplace import Laplace
 from probability.distributions.continuous.lomax import Lomax
 from probability.distributions.continuous.normal import Normal
